/*
 * Project: irond
 * Package: src.de.fhhannover.inform.ifmap
 * File:    Client.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.ifmap;

import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import de.fhhannover.inform.ifmap.communication.ConnectionRepository;
import de.fhhannover.inform.ifmap.control.IfmapFacade;
import de.fhhannover.inform.ifmap.properties.PropertiesRepository;
import de.fhhannover.inform.ifmap.properties.PublisherRepository;
import de.fhhannover.inform.ifmap.properties.SynchronisationService;
import de.fhhannover.inform.ifmap.view.ViewController;

public class Client {

	private final ViewController mViewController;
	private final IfmapFacade mIfmapFacade;
	
	public Client() {
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
			UIManager.put("PopupMenu.consumeEventOnClose", Boolean.TRUE);
			//UIManager.put("Button.showMnemonics", Boolean.TRUE);
		} catch (Throwable e) {
			e.printStackTrace();
		}
		PropertiesRepository mPropertiesRep = new PropertiesRepository();
		ConnectionRepository mConnectionRep = new ConnectionRepository();
		PublisherRepository mPublisherRep = new PublisherRepository();
		SynchronisationService mSyncService = new SynchronisationService(mPropertiesRep, 
				mConnectionRep, mPublisherRep);
		mSyncService.init();
		mIfmapFacade = new IfmapFacade(mSyncService);
		mViewController = new ViewController(mIfmapFacade);		
	}
	
	public void start(){		
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				mViewController.showMainFrame();
			}
		});
	}
	
	public static void main(String[] args) {
		Client client = new Client();
		client.start();
	}
}
