/*
 * Project: irond
 * Package: src.de.fhhannover.inform.ifmap.view.component
 * File:    ToolbarPanel.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.ifmap.view.component;

import java.awt.BorderLayout;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;

import de.fhhannover.inform.ifmap.util.ResourceHelper;

public class ToolbarPanel extends JToolBar {
	private static final long serialVersionUID = 2814752100004120354L;
	public JButton buttonConnections;
	public JButton buttonPublisher;
	
	private JLabel labelIron;
	private JLabel labelEsukom;
	private JLabel labelTrust;	
	
	public ToolbarPanel() {
		
		buttonConnections = new JButton("");		
		add(buttonConnections);
		buttonConnections.setToolTipText("Manage IF-MAP connections");
		//buttonConnections.setPreferredSize(new Dimension(48, 48));
		buttonConnections.setFocusable(false);
		buttonConnections.setIcon(ResourceHelper.getImage("computer_add.png"));
		
		buttonPublisher = new JButton("");
		add(buttonPublisher);
		buttonPublisher.setToolTipText("Show known publisher and change their colors");
		//buttonPublisher.setPreferredSize(new Dimension(48, 48));
		buttonPublisher.setFocusable(false);
		buttonPublisher.setIcon(ResourceHelper.getImage("color_management.png"));
		
		add(Box.createHorizontalGlue());
		
		labelTrust = new JLabel("");
		add(labelTrust);
		labelTrust.setHorizontalAlignment(SwingConstants.RIGHT);
		labelTrust.setIcon(ResourceHelper.getImage("logo_tnc.png"));
		labelTrust.setToolTipText("Visit the Trust@FHH Website!");
		labelTrust.addMouseListener(new MouseAdapter() {
			public void mouseExited(MouseEvent evt) {
				labelTrust.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
			}
			public void mouseEntered(MouseEvent evt) {
				labelTrust.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
			}
			public void mouseClicked(MouseEvent evt) {
				de.fhhannover.inform.ifmap.util.AppLauncher.openWebpageInBrowser("http://trust.inform.fh-hannover.de");
			}
		});
		
		labelIron = new JLabel("");
		add(labelIron);
		labelIron.setIcon(ResourceHelper.getImage("logo_iron.png"));
		labelIron.setHorizontalAlignment(SwingConstants.RIGHT);
		labelIron.setToolTipText("More interesting IFMAP-stuff");
		labelIron.addMouseListener(new MouseAdapter() {
			public void mouseExited(MouseEvent evt) {
				labelIron.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
			}
			public void mouseEntered(MouseEvent evt) {
				labelIron.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
			}
			public void mouseClicked(MouseEvent evt) {
				de.fhhannover.inform.ifmap.util.AppLauncher.openWebpageInBrowser("http://trust.inform.fh-hannover.de/joomla/index.php/projects/iron");
			}
		});
		
		labelEsukom = new JLabel("");
		add(labelEsukom);
		labelEsukom.setHorizontalAlignment(SwingConstants.RIGHT);
		labelEsukom.setIcon(ResourceHelper.getImage("esukom_32x32.png"));
		labelEsukom.setToolTipText("ESUKOM Project-Homepage");
		labelEsukom.addMouseListener(new MouseAdapter() {
			public void mouseExited(MouseEvent evt) {
				labelEsukom.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
			}
			public void mouseEntered(MouseEvent evt) {
				labelEsukom.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
			}
			public void mouseClicked(MouseEvent evt) {
				de.fhhannover.inform.ifmap.util.AppLauncher.openWebpageInBrowser("http://www.esukom.de/");
			}
		});
	}
}
